
/*                                         READ ME
LABOR MARKET SCARRING IN A DEVELOPING ECONOMY: STIGMA VERSUS LOST HUMAN CAPITAL FROM PLANT CLOSING IN MEXICO

This README note is also the MASTER DO FILE that has to be run to obtain all the results from the paper. 
It consists of two parts. The first part builds the datasets taking as input the gross labor surveys from 
the Mexican National Institute of Statistics (INEGI).

Part I of this file runs 6 individual do-files that process gross files and merge them into the 
unified dataset used in the econometric analysis of part II.

Part II runs 7 individual do-files with the statistical analysis and derives all the results of the paper. Next to each of the do-files is the description of the files containing the results.

PS. For STATA install: outreg2, parmest 
*/


clear
version 18.0
set more off
set varabbrev on

global root   = "C:/WBG/Rep-checks/RR_MEX_2025_353"
global dofile = "${root}/DoFiles_ScarringMX_0525"
sysdir set PLUS "${dofile}/ado"


/*
The paper uses the Mexican Labor Survey (ENOE) for the periods with special questionnaire, which are the following: 1Q/2005, 2Q/2005, 3Q/2005, 4Q/2005, 1Q/2006, 2Q/2006, 2Q/2007, 2Q/2008, 1Q/2009, 1Q/2010, 1Q/2011, 1Q/2012, 1Q/2013, 1Q/2014, 1Q/2015, 1Q/2016, 1Q/2017 and 1Q/2018.
For each quarter, the file contains 4 databases: Questionnaire 1, Questionnaire 2, Socio-demographics, Household members.
*/

*PART I  

run "${dofile}/destring_1.do"

run "${dofile}/cuest1_1.do"

run "${dofile}/cuest2_1.do"

run "${dofile}/hogt_1.do"

run "${dofile}/sdemt_1.do"

run "${dofile}/database_1.do"


*PART II. OBTAINING THE RESULTS. 
																	*RESULTS

do "${dofile}/Table_1to3.do"  /*from here, in folder Results all the results. You will find Stats_pc.smcl , which contains Tables 1,2 and 3 plus ANNEX Tables A4 and A5 */

run "${dofile}/Table_4_5_A1_A2.do"  /*from here, you will find in Results regb_0518.xls (Table 4 , Table A1 , Table A2) and reged_0518.xls (Table 5)*/

run "${dofile}/Figure1_to_Figure9.do" /*from here: Figure 1 (closing_lrw_hour.xls); Figure 2 (closing_hours_work.xls); Figure 3 (closing_informal.xls)
									              Figure 4 (quit_lrw_hour.xls)   ; Figure 5 (quit_hours_work.xls)    ; Figure 6 (quit_informal.xls)
                                                  Figure 7 (cob_lrw_hour.xls )   ; Figure 8 (cob_hours_work.xls)     ; Figure 9 (cob_informal.xls)
											   */
					   
run "${dofile}/Figure12_to_Figure15.do" /* from here: Figure 12 (heted1_lrw_hour.xls & heted2_lrw_hour.xls) ; Figure 13 (closinged1_hours_work.xls & closinged2_hours_work.xls)
								   Figure 14 (closinged1_informal.xls & closinged2_informal.xls) ; Figure 15 (hetsx1_lrw_hour.xls & hetsx2_lrw_hour.xls)
                                  */

/*Figures 10 and 11 are descriptive statistics on unemployment and we constructed the graphs in EXCEL using direct data from the National Institute of Statistics. Here we did not use STATA.  https://www.inegi.org.mx/app/indicadores/?tm=0&ind=454808#D454808   */

run "${dofile}/base_bfafter.do"              /*Here this file use the rotative panel of the labor survey and construct 
                                            the before and after follow up of workers. */
	
run "${dofile}/Table_6.do"     /*Table 6 in DID_t6.xls */ 

run "${dofile}/Figure_16"                    /* Figure 16. The results are export to an EXCEL file named fe_industry.xsl (No of observations in reg_ind.xls). In the first column is the beta estimate and in the last two columns are the intervals of the figure*/

*Table 7 incorporates previous results and only adds new results for columns (2) and (3)
run "${dofile}/Table_7.do"     /*Table 7 RESULTS FOR COLUMNS 2 (Est. w/o FE common sample) and column 4 (No. Obs.). Notice that columns 3 and 6 are givey by: C3=1-(C1/C2) and C6= 1-(C1/C5). */

*Table A3 incorporates previous results and only adds new results for columns (2) and (3)
do "${dofile}/Table_A3.do"     /* Table A3 in log using "`results'\Table_A3", replace*/
