	
*Construction of dataset

clear
set more off
local path_do = "${dofile}"
local path_original = "${root}/ENOE"
local path_data = "${root}/ENOE/Cleandata"


foreach k of num 105 205 305 405 106 206 207 208 109 110 111 112 113 114 115 116 117 118 {

	use "`path_data'/coe2t`k'm.dta", clear
	
	*Survey
	nsplit per, digits(1 2) generate(quarter_survey year)
	drop per year
	
	egen period = concat(quarter_survey year_survey)
	destring period, replace force

	sort cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren, stable
	
	*Merge with coe1t
	merge 1:1 cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren using "`path_data'/coe1t`k'm.dta", keepusing(work_lw work r_nwork_lw ownbus year_beginwork month_search year_search month_end year_end contract industry)
	drop if _merge == 2
	drop _merge
	
	*Merge with sdemt
	merge 1:1 cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren using "`path_data'/sdemt`k'm.dta", keepusing(relation sex age day_birth month_birth year_birth city_birth1 edu aedu year_school prof children marital loc mun size_loc pea lab_status sector  industry1 w_month informal formal literacy end_prof attend_school emp_status acc_health hours_work w_hour tot_jobs)
	drop if _merge == 2
	drop _merge
	
	*Merge with hogt
	merge m:1 cd_a ent con n_pro_viv v_sel n_hog h_mud using "`path_data'/hogt`k'm.dta", keepusing(month_int year_int)
	drop if _merge == 2
	drop _merge

	tempfile me_`k'
	save `me_`k''.dta, replace

}

*Keep first interviews
use `me_105'.dta, clear
keep if n_ent == 1
save `me_105'.dta, replace

use `me_205'.dta, clear
keep if n_ent == 1
save `me_205'.dta, replace

use `me_106'.dta, clear
keep if n_ent == 5
save `me_106'.dta, replace

use `me_206'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_206'.dta, replace

use `me_207'.dta, clear
keep if n_ent == 1 | n_ent == 5 
save `me_207'.dta, replace

use `me_208'.dta, clear
keep if n_ent == 2 | n_ent == 5
replace n_ent = 1 if n_ent == 2
save `me_208'.dta, replace

use `me_109'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_109'.dta, replace

use `me_110'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_110'.dta, replace

use `me_111'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_111'.dta, replace

use `me_112'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_112'.dta, replace

use `me_113'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_113'.dta, replace

use `me_114'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_114'.dta, replace

use `me_115'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_115'.dta, replace

use `me_116'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_116'.dta, replace

use `me_117'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_117'.dta, replace

use `me_118'.dta, clear
keep if n_ent == 1 | n_ent == 5
save `me_118'.dta, replace


use `me_105'.dta, clear

foreach k of num 205 106 206 207 208 109 110 111 112 113 114 115 116 117 118 {
	
	append using `me_`k''.dta, force

}

tempfile did_0518
save `did_0518', replace

    merge m:1 period using "`path_data'/cpi_quar.dta", keepusing(cpi_2005)
	drop _merge

	
	* Labor force Status
	gen lab_st = .
		*Out of labor force
		replace lab_st = 0 if pea == 2 
		*Employed
		replace lab_st = 1 if lab_status == 1 & pea == 1
		*Unemployed
		replace lab_st = 2 if lab_status == 2 & pea == 1
	
		label define u8 0 "Out of labor force" 1 "Employed" 2 "Unemployed"
		label value lab_st u8
		label var lab_st "Labor force status"

	* Type of displacement (definition 1)
	*Non-displaced workers (igual a los que no perdieron un trabajo y a los que no contestaron esa pregunta)
	gen type_disp1 = 0 if r_unemp_ans == 0
		*Plant closing (includes downsizing of staff)
		replace type_disp1 = 1 if r_unemp_ans == 1 & (r_lost == 1 | r_lost == 2)
		*Fired (includes not called again and end of contract)
		replace type_disp1 = 2 if r_unemp_ans == 1 & (r_lost == 6 | r_lost == 4 | r_lost == 5)
		*Quit
		*No incluye empleadores que renuncian
		replace type_disp1 = 3 if r_unemp_ans == 1 & r_unemp == 2
		*Closed own bussiness
		replace type_disp1 = 4 if r_unemp_ans == 1 & r_unemp == 3
		*Retired
		replace type_disp1 = 5 if r_unemp_ans == 1 & r_unemp == 4
		*Other
		replace type_disp1 = 6 if (r_unemp_ans == 1 & (r_lost == 3 | r_lost == 7 | r_lost == 9)) | (r_unemp_ans == 1 & (r_unemp == 5 | r_unemp == 6 | r_unemp == 7))
		
		label define p778 0 "Non-displaced" 1 "Plant Closing" 2 "Fired" 3 "Quit" 4 "Closed Own Bussiness" 5 "Retirement" 6 "Other"
		label value type_disp1 p778
		label var type_disp1 "Type of displacement (definition 1)"

	* Type of displacement (definition 2)
	*Non-displaced workers (igual a los que no perdieron un trabajo y a los que no contestaron esa pregunta)
	gen type_disp2 = 0 if r_unemp_ans == 0
		*Plant closing (does not include downsizing of staff)
		replace type_disp2 = 1 if r_unemp_ans == 1 & r_lost == 1 
		*Fired (does not include not called again and end of contract)
		replace type_disp2 = 2 if r_unemp_ans == 1 & r_lost == 6
		*Quit
		*No incluye empleadores que renuncian
		replace type_disp2 = 3 if r_unemp_ans == 1 & r_unemp == 2
		*Closed own bussiness
		replace type_disp2 = 4 if r_unemp_ans == 1 & r_unemp == 3
		*Retired
		replace type_disp2 = 5 if r_unemp_ans == 1 & r_unemp == 4
		*Other
		replace type_disp2 = 6 if (r_unemp_ans == 1 & (r_lost == 2 | r_lost == 3 | r_lost == 7 | r_lost == 9 | r_lost == 4 | r_lost == 5)) | (r_unemp_ans == 1 & (r_unemp == 5 | r_unemp == 6 | r_unemp == 7))
		
		label define p7788 0 "Non-displaced" 1 "Plant Closing" 2 "Fired" 3 "Quit" 4 "Closed Own Bussiness" 5 "Retirement" 6 "Other"
		label value type_disp2 p7788
		label var type_disp2 "Type of displacement (definition 2)"
		
	* Type of displacement (Definition 3)
	*Non-displaced workers
	gen type_disp3 = 0 if lab_st == 1
		*Plant closing (includes downsizing of staff)
		replace type_disp3 = 1 if r_unemp == 1 & (r_lost == 1 | r_lost == 2)
		*Fired (includes not called again and end of contract)
		replace type_disp3 = 2 if r_unemp == 1 & (r_lost == 6 | r_lost == 4 | r_lost == 5)
		*Quit
		*No incluye empleadores que renuncian
		replace type_disp3 = 3 if r_unemp == 2
		*Closed own bussiness
		replace type_disp3 = 4 if r_unemp == 3
		*Retired
		replace type_disp3 = 5 if r_unemp == 4
		*Other
		replace type_disp3 = 6 if r_unemp == 5 | r_unemp == 6 | r_unemp == 7 | r_unemp == 8 | r_unemp == 9
		
		label define p7l 0 "Non-displaced" 1 "Plant Closing" 2 "Fired" 3 "Quit" 4 "Closed Own Bussiness" 5 "Retirement" 6 "Other"
		label value type_disp3 p7l
		label var type_disp3 "Type of displacement (definition 3)"
	
	* Type of displacement (Definition 4)
	*Non-displaced workers
	gen type_disp4 = 0 if lab_st == 1
		*Plant closing
		replace type_disp4 = 1 if r_unemp == 1 & r_lost == 1 
		*Fired (includes not called again, end of contract and downsizing of staff)
		replace type_disp4 = 2 if r_unemp == 1 & (r_lost == 6 | r_lost == 4 | r_lost == 5 | r_lost == 2)
		*Quit
		*No incluye empleadores que renuncian
		replace type_disp4 = 3 if r_unemp == 2
		*Closed own bussiness
		replace type_disp4 = 4 if r_unemp == 3
		*Retired
		replace type_disp4 = 5 if r_unemp == 4
		*Other
		replace type_disp4 = 6 if r_unemp == 5 | r_unemp == 6 | r_unemp == 7 | r_unemp == 8 | r_unemp == 9
		
		label define p7o 0 "Non-displaced" 1 "Plant Closing" 2 "Fired" 3 "Quit" 4 "Closed Own Bussiness" 5 "Retirement" 6 "Other"
		label value type_disp4 p7o
		label var type_disp4 "Type of displacement (definition 4)"

	* Type of displacement (Definition 5)
	*Non-displaced workers
	gen type_disp5 = 0 if lab_st == 1
		*Plant closing
		replace type_disp5 = 1 if r_unemp == 1 & r_lost == 1 
		*Fired (does not includes not called again, end of contract and downsizing of staff)
		replace type_disp5 = 2 if r_unemp == 1 & r_lost == 6
		*Quit
		*No incluye empleadores que renuncian
		replace type_disp5 = 3 if r_unemp == 2
		*Closed own bussiness
		replace type_disp5 = 4 if r_unemp == 3
		*Retired
		replace type_disp5 = 5 if r_unemp == 4
		*Other
		replace type_disp5 = 6 if r_unemp == 5 | r_unemp == 6 | r_unemp == 7 | r_unemp == 8 | r_unemp == 9
		
		label define p7y 0 "Non-displaced" 1 "Plant Closing" 2 "Fired" 3 "Quit" 4 "Closed Own Bussiness" 5 "Retirement" 6 "Other"
		label value type_disp5 p7y
		label var type_disp5 "Type of displacement (definition 5)"

	*Real wages
	replace w_hour = . if w_hour == 0
	gen rw_hour = w_hour/cpi_2005*100
	gen rw_week = w_week/cpi_2005*100
	gen lrw_hour = log(rw_hour)
	
	*Current tenure
	gen tenure = year_survey - year_beginwork if lab_st == 1 
		label var tenure "Current tenure"
	
	sum tenure, d
	gen t_tenure = inrange(tenure,`r(p1)',`r(p99)')
		label var t_tenure "Touse: tenure"

	* Years from survey that you lost your job 
	gen years_unemp = year_survey - year_lost
		replace years_unemp = 0 if type_disp3 == 0
		label var years_unemp "Number of years from survey that you lost job"

	*Number of years between year you lost job and year you began in current job
	gen years_disp = .
		replace years_disp = year_beginwork - year_lost
		replace years_disp = . if years_disp < 0
		label var years_disp "Number of years between year you lost job and year you began in current job"
	
	sum tenure, d
	gen t_years_disp = inrange(years_disp,`r(p1)',`r(p99)')
		label var t_years_disp "Touse: years_disp"

	* Touse: weekly hours worked
	sum hours_work, d
	gen t_hours_work = inrange(hours_work,`r(p1)',`r(p99)')
		label var t_hours_work "Touse: weekly hours worked"
		
	* Touse: real hourly wage
	sum rw_hour, d
	gen t_rw_hour = inrange(rw_hour,`r(p1)',`r(p99)')
		label var t_hours_work "Touse: real hourly wage"

	*Square of age
	gen age2 = age^2
	
	* Duration of unemployment
	gen aux1 = 12 - month_search
	gen aux2 = (year_end - year_search - 1)*12
	gen unemp_length = .
		replace unemp_length = month_end - month_search if year_end == year_search
		replace unemp_length = aux1 + aux2 + month_end if year_end > year_search
		label var unemp_length "Duration of unemployment (in months)"
	replace unemp_length = 0 if unemp_length == .
	drop aux1 aux2
		
	*Dummies
	tab type_disp3, gen(type_disp3_)
	tab sex, gen(sex_)
	
	* Lags
	replace years_unemp = . if years_unemp > 30
	replace years_unemp = 10 if years_unemp >= 10 & years_unemp <= 30
*	replace years_unemp = years_unemp + 1

	* Plant closing
	gen lag_closing = years_unemp * type_disp3_2 if type_disp3_2 == 1
		replace lag_closing = 0 if type_disp3_2 == 0

	tab lag_closing, gen(lag_closing_)
	
	*Fired
	gen lag_fired = years_unemp * type_disp3_3 if  type_disp3_3 == 1
		replace lag_fired = 0 if type_disp3_3 == 0

	tab lag_fired, gen(lag_fired_)

	*Quit
	gen lag_quit = years_unemp * type_disp3_4 if  type_disp3_4 == 1
		replace lag_quit = 0 if type_disp3_4 == 0

	tab lag_quit, gen(lag_quit_)

	*Closed own bussines
	gen lag_cob = years_unemp * type_disp3_5 if  type_disp3_5 == 1
		replace lag_cob = 0 if type_disp3_5 == 0

	tab lag_cob, gen(lag_cob_)

	*The paper restricts the sample to:
	drop if age < 15 | age > 65
	keep if relation == 1 | relation == 2 | relation == 3
	drop if ((year_birth > year_survey) & year_birth != .) | ((year_beginwork < year_birth) & year_birth != .) | ((year_search < year_birth) & year_birth != .) | ((year_end < year_birth) & year_birth != .) | ((year_lost < year_birth) & year_birth != .) | ((year_lost > year_survey) & year_lost != .) | ((year_beginwork > year_survey) & year_beginwork != .) | ((year_search > year_end) & year_search != .)

	*Id
	sort cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren year_survey quarter_survey n_ent, stable
	egen id = group(cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren)
	drop if id == .

	sort id, stable

	bys id: gen dup = cond(_N==1,0,_n)
	drop if dup == 0
	
	bys id: gen aux = 1 if year_survey[_n] == year_survey[_n-1] + 1
	bys id: replace aux = 1 if aux[_n+1] == 1
	drop if aux == .
	
	bys id: gen dup1 = cond(_N==1,0,_n)
	drop if dup1 > 2
	
	drop id
	sort cd_a ent con v_sel n_pro_viv n_hog h_mud n_ren year_survey quarter_survey n_ent, stable
	egen id = group(cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren)
	drop if id == .

	sort id n_ent, stable
	drop aux
	bys id: gen aux = 1 if n_ent[_n] == n_ent[_n-1]
		bys id: replace aux = 1 if n_ent[_n] == n_ent[_n+1]
	
	drop if aux == 1
	drop aux
	
	drop id
	sort cd_a ent con v_sel n_pro_viv n_hog h_mud n_ren year_survey quarter_survey n_ent, stable
	egen id = group(cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren)
	drop if id == .

	sort id year_survey quarter_survey n_ent, stable

	keep cd_a ent con v_sel n_pro_viv n_hog h_mud n_ren id n_ent year_survey quarter_survey period loc size_loc mun relation sex sex_* age age2 day_birth month_birth year_birth city_birth1 edu aedu prof children marital sector industry industry1 informal formal literacy end_prof attend_school contract pea lab_st emp_status freq_w w w_month w_week rw_week hours_work w_hour rw_hour lrw_hour acc_health medat tot_jobs year_beginwork tenure month_search year_search month_end year_end unemp_length r_unemp_ans unemp r_unemp r_lost year_lost month_lost industry_lost years_unemp years_disp type_disp* type_disp3_* lag_* cpi_2005 fac t_tenure t_years_disp t_hours_work t_rw_hour
	
	order cd_a ent con v_sel n_pro_viv n_hog h_mud n_ren id n_ent year_survey quarter_survey period loc size_loc mun relation sex age age2 day_birth month_birth year_birth city_birth1 edu aedu prof children marital sector industry industry1 informal formal literacy end_prof attend_school contract pea lab_st emp_status freq_w w w_month w_week rw_week hours_work w_hour rw_hour lrw_hour acc_health medat tot_jobs year_beginwork tenure month_search year_search month_end year_end unemp_length r_unemp_ans unemp r_unemp r_lost year_lost month_lost industry_lost years_unemp years_disp type_disp* cpi_2005 fac t_tenure t_years_disp t_hours_work t_rw_hour
	
	
	*Interview number 1 (initial)
	bys id: gen lrw_hour_i = lrw_hour if n_ent == 1
		bys id: replace lrw_hour_i = lrw_hour_i[_n-1] if n_ent == 5
 	
	clonevar lab_st_i = lab_st if n_ent == 1
		replace lab_st_i = lab_st_i[_n-1] if n_ent == 5

	clonevar emp_status_i = emp_status if n_ent == 1
		replace emp_status_i = emp_status_i[_n-1] if n_ent == 5
		
	clonevar industry_i = industry if n_ent == 1
		replace industry_i = industry_i[_n-1] if n_ent == 5
	
	bys id: gen hours_work_i = hours_work if n_ent == 1
		bys id: replace hours_work_i = hours_work_i[_n-1] if n_ent == 5

	clonevar contract_i = contract if n_ent == 1
		replace contract_i = contract_i[_n-1] if n_ent == 5

	clonevar informal_i = informal if n_ent == 1
		replace informal_i = informal_i[_n-1] if n_ent == 5
	
	clonevar formal_i = formal if n_ent == 1
		replace formal_i = formal_i[_n-1] if n_ent == 5

	clonevar acc_health_i = acc_health if n_ent == 1
		replace acc_health_i = acc_health_i[_n-1] if n_ent == 5

	bys id: gen age_i = age if n_ent == 1
		bys id: replace age_i = age_i[_n-1] if n_ent == 5

	bys id: gen relation_i = relation if n_ent == 1
		bys id: replace relation_i = relation_i[_n-1] if n_ent == 5

	clonevar marital_i = marital if n_ent == 1
		replace marital_i = marital_i[_n-1] if n_ent == 5
	
	bys id: gen aedu_i = aedu if n_ent == 1
		bys id: replace aedu_i = aedu_i[_n-1] if n_ent == 5

	bys id: gen ent_i = ent if n_ent == 1
		bys id: replace ent_i = ent_i[_n-1] if n_ent == 5

	*Keep if interview == 5
	keep if n_ent == 5
	
	*Generate difference
	gen dlrw_hour = lrw_hour - lrw_hour_i
	label var dlrw_hour "Difference in real hourly wage between 1st and 5th interview"
	
	sum dlrw_hour, d
	gen t_dlrw_hour = inrange(dlrw_hour,`r(p1)',`r(p99)')
		label var t_dlrw_hour "Touse: difference in real hourly wage" 

	gen dhours_work = hours_work - hours_work_i
	label var dhours_work "Difference in weekly hours of work between 1st and 5th interview"
	
	sum dhours_work, d
	gen t_dhours_work = inrange(dhours_work,`r(p1)',`r(p99)')
		label var t_dhours_work "Touse: difference in weekly hours of work" 
	
	gen dinformal = informal - informal_i
	label var dinformal "Difference in type of employment between 1st and 5th interview"

	gen dacc_health = acc_health - acc_health_i
	label var dacc_health "Difference in access to health between 1st and 5th interview"

	gen age_i2 = age_i^2
	
	gen closing = .
	replace closing = 1 if type_disp3 == 1
	replace closing = 0 if type_disp3 == 0
	
	gen closing1 = .
	replace closing1 = 1 if type_disp3 == 1
	replace closing1 = 0 if type_disp3 != 1 & type_disp3 != .

	
	save "`path_data'/did_0518.dta", replace

	

	
	
	
