* Prepare dataset 
* Socio-demographic dataset: sdemt

clear
set more off
local path_do = "${dofile}"
local path_original = "${root}/ENOE"
local path_data = "${root}/ENOE/Cleandata"

foreach k of num 105 205 305 405 106 206 207 208 109 110 111 112 113 114 115 116 117 118 {

	use "`path_data'/sdemt`k'.dta", clear
	
	*The Coe1t and coe2t is done to individuals with c_res == 1 | c_res == 3 and age > 12
	drop if c_res == 2
	drop if eda < 12
	
	label var loc "Locality"
	label var mun "Municipality"
	
	rename t_loc size_loc
		label define j1 1 "More than 100,000 inhabitants" 2 "Between 15,000-99,999 inhabitants" 3 "Between 2,500-14,999 inhabitants" 4 "Less than 2,500 inhabitants"
		label value size_loc j1
		label var size_loc "Size of locality"

	nsplit par_c, digits(1) gen(relation) 
		drop par_c relation2 relation3
		rename relation1 relation
		label define rel 1 "Head of household" 2 "Husban/Wife" 3 "Son/Daughter"
		label value relation rel 
		label var relation "Parental condition"
	
	label define sx 1 "Male" 2 "Female"
	label value sex sx
	label var sex "Sex"
	
	rename eda age
		label var age "Age"
		
	rename nac_dia day_birth
		replace day_birth = . if day_birth == 99
	rename nac_mes month_birth
		replace month_birth = . if month_birth == 99
	rename nac_anio year_birth
		replace year_birth = . if year_birth == 9999
		label var day_birth "Day of birth"
		label var month_birth "Month of birth"
		label var year_birth "Year of birth"

	capture rename l_nac city_birth1
	capture rename l_nac_c city_birth2
	
	rename cs_p13_1 edu 
		label define edu1 0 "None" 1 "Preschool" 2 "Primary" 3 "Secondary" 4 "Bachiller" 5 "Normal" 6 "Technical" 7 "Professional" 8 "Master" 9 "PhD" 99 "Do not know" 
		label value edu edu1
		label var edu "Category of education"
	
	rename cs_p13_2 year_school
		label var year_school "Aproved years at school"
		
	rename cs_p14_c prof
		label var prof "Profession"
	
	rename cs_p16 end_prof
		replace end_prof = . if end_prof == 9
		label define o8 1 "Yes" 2 "No"
		label value end_prof o8
		label var end_prof "Have you finished the subjects of the career?"
	
	rename cs_p17 attend_school
		replace attend_school = . if attend_school == 9
		label define oy 1 "Yes" 2 "No"
		label value attend_school oy
		label var attend_school "Do you attend school?"

	rename n_hij children
		replace children = . if children == 99
		label var children "Number of children"
		
	rename e_con marital
		replace marital = . if marital == 9
		label define e1 1 "Free Union" 2 "Separate" 3 "Divorce" 4 "Widower" 5 "Married" 6 "Single" 
		label value marital e1
		label var marital "Marital status"

	rename clase1 pea
		replace pea = . if pea == 0
		label define w1 1 "Economically active population" 2 "Non-economically active population"
		label value pea w1
		label var pea "Economically and non-economically active population"

	rename clase2 lab_status
		label define y1 1 "Employed population" 2 "Unemployed population" 3 "Available" 4 "Non-available"
		label value lab_status y1
		label var lab_status "Laboral status"

	rename rama_est1 sector
		replace sector = . if sector == 0 | sector == 4
		label define t1 1 "Primary" 2 "Secondary" 3 "Tertiary"
		label value sector t1
		label var sector "Activity sector"

	rename rama_est2 industry1
		replace industry1 = . if industry1 == 0
		label define p1 1 "Agriculture" 2 "Mining and electricity" 3 "Manufacturing" 4 "Construction" 5 "Wholesale" 6 "Hotels and restaurants" 7 "Transport and communications" 8 "Professional and financial services" 9 "Social services" 10 "Other services" 11 "Public Administration" 
		label value industry1 p1
		label var industry1 "Industry1"

	rename anios_esc aedu
		replace aedu = . if aedu == 99
		label var aedu "Years of education"
	
	rename hrsocup hours_work
		replace hours_work = . if hours_work == 99 | hours_work == 0
		label var hours_work "Weekly hours of work"
		
	rename ingocup w_month
		label var w_month "Monthly income"
	
	rename ing_x_hrs w_hour
		replace w_hour = . if w_hour == 0
		label var w_hour "Hourly wage"
	
	rename emp_ppal informal
		replace informal = . if informal == 0
		label define z1 1 "Informal" 2 "Formal"
		label value informal z1
		label var informal "Informal or Formal employment"
		
	gen formal = .
	replace formal = 1 if informal == 2
	replace formal = 0 if informal == 1
		label define z111 0 "Informal" 1 "Formal"
		label value formal z111
		label var formal "Informal or Formal employment"

	rename cs_p12 literacy
		replace literacy = . if literacy == 9
			label define z188 1 "Yes" 2 "No"
		label value literacy z188

		label var literacy "Do you know how to read and write?"
		
	rename pos_ocu emp_status
		replace emp_status = . if emp_status == 0
		label define r4 1 "Employee" 2 "Employer" 3 "Self-employed" 4 "Unpaid worker" 
		label value emp_status r4
		label var emp_status "Employed status"
	
	rename seg_soc acc_health
		replace acc_health = . if acc_health == 0 | acc_health == 3
		label define r9 1 "With access" 2 "Without access" 3 "Unspecified" 
		label value acc_health r9
		label var acc_health "Access to health institutions"

	rename t_tra tot_jobs
		replace tot_jobs = . if tot_jobs == 0
		label define r78 1 "One job" 2 "Two jobs"
		label value tot_jobs r78
		label var tot_jobs "Total of jobs"
	
	rename tue_ppal informal_unit
		label define z17 1 "Informal sector" 2 "Out of informal sector"
		label value informal_unit z17
		label var informal_unit "Type of the economic unit of principal work"

	capture keep r_def cd_a ent con upm d_sem n_pro_viv v_sel n_hog h_mud n_ent per n_ren eda n_inf year_survey relation sex age day_birth month_birth year_birth city_birth1 city_birth2 edu aedu year_school prof children marital loc mun size_loc pea lab_status sector industry1 w_month informal formal literacy end_prof attend_school emp_status acc_health hours_work w_hour tot_jobs
	
	sort cd_a ent con n_pro_viv v_sel n_hog h_mud n_ren, stable

	save "`path_data'/sdemt`k'm.dta", replace
	
}


clear




	
	
